@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 use Exporter;
 our @ISA = qw(Exporter);
@@ -42,13 +42,15 @@ sub crypt {
 
     # first use SSHA512
     $salt  = substr(Digest::MD5::md5_base64(UUID::Random::generate()), 0, 16);
+    $salt =~ tr/\+/./;
     $crypt = CORE::crypt($pass, '$6$'.$salt.'$');
-    return $crypt if crypt_type($crypt) eq 'SSHA512';
+    #say "D:salt=$salt, crypt=$crypt";
+    return $crypt if (crypt_type($crypt)//"") eq 'SSHA512';
 
     # fallback to MD5-CRYPT if failed
     $salt = substr($salt, 0, 8);
     $crypt = CORE::crypt($pass, '$1$'.$salt.'$');
-    return $crypt if crypt_type($crypt) eq 'MD5-CRYPT';
+    return $crypt if (crypt_type($crypt)//"") eq 'MD5-CRYPT';
 
     # fallback to CRYPT if failed
     $salt = substr($salt, 0, 2);
@@ -68,7 +70,7 @@ Crypt::Password::Util - Crypt password utilities
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
